# ADattribution

#### 介绍
广告归因

1.  依赖管理
- 生成依赖
```shell script
pip3 freeze > requirements.txt
```
- 安装依赖
```shell script
pip3 install -r requirements.txt -i https://mirrors.aliyun.com/pypi/simple
```
- 虚拟环境管理
```text
创建虚拟环境：python3 -m venv venv
激活虚拟环境：source venv/bin/activate

退出虚拟环境：deactivate
```
